#!/usr/bin/env python

"""parseli (save, rows o' json, and time)"""

__version__ = "0.0.44"
__author__ = [
    "Mek <michael.karpeles@gmail.com>"
]
__license__ = "public domain"
__contributors__ = "see AUTHORS"

from parseli import getli, crawli, parseli
